MCARotator
==========

.. currentmodule:: xeofs.cross

.. autoclass:: MCARotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MCARotator.__init__
      ~MCARotator.components
      ~MCARotator.compute
      ~MCARotator.correlation_coefficients_X
      ~MCARotator.correlation_coefficients_Y
      ~MCARotator.covariance_fraction_CD95
      ~MCARotator.cross_correlation_coefficients
      ~MCARotator.deserialize
      ~MCARotator.fit
      ~MCARotator.fraction_variance_X_explained_by_X
      ~MCARotator.fraction_variance_Y_explained_by_X
      ~MCARotator.fraction_variance_Y_explained_by_Y
      ~MCARotator.get_params
      ~MCARotator.get_serialization_attrs
      ~MCARotator.heterogeneous_patterns
      ~MCARotator.homogeneous_patterns
      ~MCARotator.inverse_transform
      ~MCARotator.load
      ~MCARotator.predict
      ~MCARotator.save
      ~MCARotator.scores
      ~MCARotator.serialize
      ~MCARotator.squared_covariance_fraction
      ~MCARotator.transform
   
   

   
   
   